Collection
==========

.. autofunction:: sokoenginepy.io.is_blank

.. autoclass:: sokoenginepy.io.Collection
    :members:
    :undoc-members:


.. autoclass:: sokoenginepy.io.Rle
    :members:
    :undoc-members:
